##  Viewing Issues on Fact Sheets
After you link a Jira issue to a fact sheet, you can view the details for the linked Jira issue on the Resources tab of the corresponding fact sheet.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274c74537a441014aa49d58bb1698baa_LowRes.png)
